#
# spec file for package idzebra
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           idzebra
Version:        2.2.7
Release:        1.4
Summary:        Fielded Free Text Engine with a Z39.50 Frontend
License:        GPL-2.0-or-later
Group:          Productivity/Databases/Servers
URL:            https://www.indexdata.com/resources/software/zebra/
Source:         https://ftp.indexdata.com/pub/zebra/idzebra-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(readline)
BuildRequires:  pkgconfig(tcl)
BuildRequires:  pkgconfig(yaz)
Requires:       yaz

%description
Zebra is a fielded free text indexing and retrieval engine with a
Z39.50 front-end. You can use any compatible, commercial, or freeware
Z39.50 client to access data stored in Zebra.

%package devel
Summary:        Fielded Free Text Engine with a Z39.50 Frontend
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       glibc-devel
Requires:       libyaz-devel

%description devel
Zebra is a fielded free text indexing and retrieval engine with a
Z39.50 front-end. You can use any compatible, commercial, or freeware
Z39.50 client to access data stored in Zebra.

%package doc
Summary:        Documentation for the idzebra Package
Group:          Productivity/Databases/Servers
Requires:       %{name} = %{version}

%description doc
This package contains the documentation for Zebra.  Zebra is a fielded
free text indexing and retrieval engine with a Z39.50 front-end.

%prep
%setup -q

%build
CFLAGS="%{optflags} -fno-strict-aliasing" \
%configure --disable-static --with-pic --with-yaz=pkg
%make_build
for f in examples/marcxml/*.x?l; do
  tr -d '\15' <$f >$f.tmp && mv $f.tmp $f
done

%check
%ifarch ix86
  # 2004-11-17 07:44:55 CET -ke-
  # there are problems with killing zebrasrv reliably
  %make_build check
%endif

%install
%make_install
# pushd doc
# make DESTDIR=%{buildroot} install
# popd
# Unwanted doc stuff
rm -fr %{buildroot}%{_datadir}/doc
#
rm -fr html
mkdir html
#ln -sf zebra.html html/index.html
cp doc/*html html
#cp doc/*.pdf .
%define DOCFILES README.md LICENSE.* NEWS
#*.pdf
{
  echo "<html><head><title>%{name} documentation directory</title></head>"
  echo "<body><ul>"
  echo "<li><a href=\"html/index.html\">%{name}</a>, official documentation (local)"
  for f in %{DOCFILES}  ; do
    if [ "http:" = "${f%%%%/*}" ]; then
      echo "<li><a href=\"$f\">$f</a>"
      continue
    fi
    [ -f $f ] || continue
    echo "<li><a href=\"$f\">$f</a>"
  done
  echo "</li></body></html>"
} >index.html
pushd %{buildroot}
  mkdir -p etc/idzebra usr/share/idzebra
  cp -a usr/share/idzebra*/tab/* etc/idzebra
  rm -fr usr/share/idzebra*/tab
  pushd %{buildroot}%{_datadir}/idzebra
  ln -sf ../../..%{_sysconfdir}/idzebra tab
  popd
popd
rm examples/*/Makefile*
rm -fr %{buildroot}%{_datadir}/idzebra-2.0-examples
find %{buildroot} -type f -name "*.la" -delete -print
find examples -type f -name '*.pl' -exec chmod -x {} \;

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%dir %{_datadir}/idzebra
%{_datadir}/idzebra/tab
%config %{_sysconfdir}/idzebra
%{_libdir}/lib*.so.*
%dir %{_libdir}/idzebra-2.0
%dir %{_libdir}/idzebra-2.0/modules
%{_libdir}/idzebra-2.0/modules/*.so
%{_bindir}/zebrasrv*
%{_bindir}/zebraidx*
%{_bindir}/idzebra*
%{_mandir}/*/*

%files devel
%{_includedir}/*
%{_datadir}/aclocal/*
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/zebra.pc

%files doc
%doc %{DOCFILES}
%doc index.html html
%doc examples
%doc doc/marc_indexing.xml

%changelog
* Mon May 29 2023 Dirk Müller <dmueller@suse.com>
- update to 2.2.7:
  * Fix Tcl not enabled by configure
  * Buffer overflow fixes and reformats
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 2.2.6:
  * zebraidx: Mention -f option when skipping index lines
  * Fix result-sets not removed in some cases
* Tue Dec  6 2022 Dirk Müller <dmueller@suse.com>
- update to 2.2.5:
  * Fix buffer overflow in dictionary insert handling. Could lead to
  * assert failures in some cases. All users should upgrade.
  * Upgrade configure.ac to version 2.69
  * Make memMax a size_t type ZEB-694 #34
  * Fix sample XSLT for Libxslt 1.1.35 ZEB-693
  * Fix #26: Index contents not shown when using "zebra::index" elements
  * in ICU mode.
  * Update XSL in example/marcxml. Thx to Jaider A. F.
  * zebra.pc fixes. Add Requires directive (so we don't have to
  * guess YAZ flags here). Simplify value for Libs, but add
  * all libs in Libs.private. Cflags: No need for I${includedir}
  * Fix #24: Do not tokenize in ICU phrase rule.
* Mon May 31 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.2.2
  * Add bf_xopen, bf_xclose, bf_alloc, bf_free symbols to keep it
    ABI compatible.
  * Bump zebra libraries from 0:1:0 to 0:2:0
  * A few typos fixed.
  * Convert some Zebra configuration files in ISO-8859-1 to UTF-8.
  * New generated pkg-config file zebra.pc
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.1.4:
  Avoid useless debug info for facet handling ZEB-682
  Perform reverse mapping for facets ZEB-601
  Update to Expat 2.2.3
  Update to Expat 2.2.3 on Windows installer
  Use Expat 2.2.2 on Windows installer ZEB-676
  Fix 'make -j no check' by serializing some tests that weren't
  supposed to be run in parallel.
  Add support for user-defined groups in mod-dom filter. A group can
  be generated with <group>-indexing element with property unit.  Unit
  is one of the known Z39.50 proximity units and defaults to "element"
  if omitted. This can be searched with @prox 0 0 0 0 k 8 which boils
  down to "same known unit=element".
  Fix compilation with Tcl 8.6 and later. Closes #4
  Zebra SCM moved to GitHub https://github.com/indexdata/idzebra
  Make packages for Ubuntu 15.10/Wily Werewolf.
  Fix incorrect scan terms with result set limit. Closes #1
  Fix documentation of of chr's equivalent directive ZEB-672
  And add a few tests for the behavior.
  Allow @attr 2=102 for numeric index
  Upgrade to debhelper version 7
  Not upgrading to version 9 now. It would move libraries and modules
  to /usr/lib/{arch}.
  Many documentation fixes. Thanks to David Crossley.
  Build: Remove Debian squeeze. Add CentOS 7. Remove Ubuntu Saucy.
  Add Ubuntu Vivid.
  Fix modulePath for examples ZEB-665
  Fix typo in path to oai-pmh example
- remove idzebra-2.0.55-tcl-8.5-abuild.patch (upstream)
* Mon Feb  9 2015 zaitor@opensuse.org
- Update to version 2.0.60:
  + Fix ICU phrase searches for terms split by ICU ZEB-664.
  + Update Visual Studio nmake file for VS 2013.
- Update Url and Source to new location.
* Tue Jun  3 2014 ke@suse.de
- Version 2.0.59; for details, see http://indexdata.dk/zebra/doc/NEWS;
  e.g.:
  * SRU 2.0 support.
  * Bug fixes.
* Wed Sep  4 2013 i@marguerite.su
- fix build with tcl 8.5+
  * tcl_interp->errorline/result is depreciated and replaced with
    Tcl_GetErrorline/Tcl_GetStringResult.
  * online documentations claim these functions were marked in 8.6
    but actually in 8.5 errorline is marked.
- add patch: idzebra-2.0.55-tcl-8.6-abuild.patch
* Thu Aug 29 2013 ke@suse.de
- Version 2.0.55; for details, see http://indexdata.dk/zebra/doc/NEWS;
  e.g.:
  + Add + document zebraidx command "check", which checks consistency
    of register.
* Wed Aug  7 2013 ro@suse.de
- fix build on factory: newer rpm does not allow to mark
  non-directories as dir anymore (like symlinks in this case)
* Thu Jun  6 2013 ke@suse.de
- Version 2.0.54; for details and earlier changes, see
  http://indexdata.dk/zebra/doc/NEWS.
* Tue Sep 18 2012 ke@suse.de
- Version 2.0.52; for details and earlier changes, see
  http://indexdata.dk/zebra/doc/NEWS.
* Wed May 25 2011 ke@suse.de
- Version 2.0.44; for details and earlier changes, see
  http://indexdata.dk/zebra/doc/NEWS:
  * Zebra honors SRU sortkeys and CQL sortby.
* Wed Aug 25 2010 ke@suse.de
- Version 2.0.44; for details see http://indexdata.dk/zebra/doc/NEWS.
* Thu Dec 17 2009 crrodriguez@opensuse.org
- fix -devel package dependencies
* Wed Nov 18 2009 ke@suse.de
- Version 2.0.43; for details see http://indexdata.dk/zebra/doc/NEWS.
* Mon May 18 2009 ke@suse.de
- Version 2.0.37; for details see http://indexdata.dk/zebra/NEWS.
* Thu Mar 26 2009 crrodriguez@suse.de
- Do not include static modules and "la" files
* Mon Mar  9 2009 ke@suse.de
- Version 2.0.36; for details see http://indexdata.dk/zebra/NEWS.
* Fri Jul  4 2008 ke@suse.de
- Version 2.0.32 (for details see NEWS):
  * Mostly ICU related enhancements and fixes.
* Wed Nov 21 2007 ke@suse.de
- Version 2.0.18 (changes since .14 from NEWS):
  * Add snippet support. Element set name zebra::snippet will make
  Zebra return an XML record with snippets.
  * Bug fixes: zebra.cfg with leading space are ignored; crash for some
  searches with customized string.chr, etc.
* Thu May 10 2007 ke@suse.de
- Version 2.0.14 (binary incompatible with version 1.x); major changes
  since 2.0.0:
  * 'isamb' is now the default ISAM system.
  * Bug fixes and performance improvements.
- New -devel subpackage.
* Thu May  3 2007 prusnak@suse.cz
- changed expat to libexpat-devel in BuildRequires
* Mon Oct 23 2006 ke@suse.de
- Version 1.3.44 (changes since .38):
  * Bugfixes: Multiple simultaneous updates by extended services trashes
    register files.
    Trailing characters in password are ignored.
  * Optimized melm performance.
* Thu Aug 17 2006 ke@suse.de
- Version 1.3.38:
  * Bug fixes.
  * Binaries renamed to zebrasrv-1.3 and zebraidx-1.3.
* Mon Jun 26 2006 ke@suse.de
- Version 1.3.36: Fix two querying related bugs.
* Thu Jun  1 2006 ke@suse.de
- Version 1.3.34:
  Bug fixes, for example fix for XPath indexing.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Nov 11 2005 ke@suse.de
- Update to version 1.3.32.
  * Fix XPath bug.
* Fri Nov  4 2005 ke@suse.de
- Update to version 1.3.30.
* Tue May 31 2005 ke@suse.de
- Update to version 1.3.28.
  * Improve authentication facility.
* Fri May 27 2005 ke@suse.de
- Update to version 1.3.26.
  * Bugfixes; for more info see NEWS.
  * Implement the 'equivalent' directive for .chr-files.
* Thu Feb 10 2005 ke@suse.de
- Update to version 1.3.24.
  * Bugfixes (white-space in records, threading support).
* Mon Jan 24 2005 ke@suse.de
- Update to version 1.3.22.
  * Various bugfixes.
  * Better indexing; ignore leading articles if wanted.
* Wed Nov 17 2004 ke@suse.de
- Update to version 1.3.18.
- Disable check on non-ix86 architectures.
* Tue Jun  1 2004 ro@suse.de
- added openssl-devel to neededforbuild
* Wed Mar 17 2004 ke@suse.de
- Add -fno-strict-aliasing to CFLAGS.
* Thu Jan 15 2004 ke@suse.de
- Update to version 1.3.15; changes:
  * Fix bug: X-Path attribute expressions with spaces in them now works.
  * Fix base address for MARC output.
* Sat Jan 10 2004 adrian@suse.de
- build as user.
* Mon Dec  1 2003 ke@suse.de
- Update to version 1.3.14; changes:
  * Fix bug with shadow and result set handling.
  * Implement MARCXML to ISO2709 conversion.
* Fri Oct 17 2003 ke@suse.de
- Update to version 1.3.13; changes:
  * Zebra ignores "unsupported use attribute" for individual databases
    when search multiple databases (unless all databases fail).
  * New filter grs.marcxml which works like grs.marc but produces MARCXML.
  * Add support for database deletion. It is possible to create/drop
    a database from zebraidx utility. Note: only for isam:b.
  * Write zebrasrv.pid to lockdir.
  * Zebra server checks for zebrasrv.pid and refuses to start if it is
    already locked by another (running) zebrasrv.
  * Bug fix: result sets were not recovered correctly. Had to
    add ODR handle for zebra_search_RPN in order to make it work.
  * Fix a bug in regx filters that didn't do anchors (^) correctly.
  * Fix a bug in searches with X-Path searches sometimes giving "extra"
    hits.
  * Fix a bug with text being chunked in pieces for the grs.xml filter.
- Enable tests.
* Thu Jun  5 2003 ke@suse.de
- Fix broken link.
* Mon May 26 2003 ke@suse.de
- Cleanup $RPM_BUILD_ROOT.
- Add missing files (*.h and /usr/bin/zebrash).
* Thu May 22 2003 ke@suse.de
- Update to version 1.3.11; changes:
  - xelm code updates. xelm works regardless state of 'xpath enable/disable'.
  - Allow multiple updates within one transaction.
  - Fix a bug with >2GB files (overflow in integer expression).
- Add yazlib and yazlib-devel to neededforbuild.
* Mon Apr 14 2003 ke@suse.de
- Update to version 1.3.10; changes:
  * Fix bug in and operation which in some cases could result in "extra"
    hits. Bug was introduced in 1.3.5.
  * Fix bug in handling of schema conversion when producing numeric tags.
  * Zvrank updates (plus documentation).
* Thu Mar 27 2003 ke@suse.de
- Update to version 1.3.8; changes:
  * Zvrank: an experimental ranking algorithm. See doc/zvrank.txt and
    source in index/zvrank.c. Enable this by using rank: zvrank in
    zebra.cfg.
  * livrank: another experimental ranking algorithm. Source in livcode.c.
    Enable this by using rank: livrank in zebra.cfg and use -DLIV_CODE=1
    for CFLAGS (no enabled on SuSE Linux by default).
  * Advanced MARC indexing. See doc/marc_indexing.xml.
  * Perl API updates and fixes.
  * Fixes: 'zebraidx delete'; a few memory leaks WRT sorting.
  * Implement 'zebraidx clean'.
* Wed Mar 26 2003 ke@suse.de
- Update to version 1.3.7; changes since 1.3.4:
  * Support Truncation 104 (CCL).
  * Implemented xelm directive.
  * Updated for newer version of YAZ (introduction of string schema).
  * Directory examples/zthes now part of distribution.
  * New .abs directive, systag, that control where to put retrieval
    information. The directive takes two arguments: system tag, element
    name.  System tag is one of : rank, sysno, size.
* Fri Nov 29 2002 ke@suse.de
- Update to version 1.3.4; changes since 1.3.0:
  * Move data1 to Zebra (used to be part of YAZ).
  * XML record reader moved from YAZ to Zebra, to make YAZ less
    dependant on external libraries.
  * Zebra server stops with a fatal error if config file cannot be read.
  * New config setting, followLinks, that controls whether update of
    files should follow symbolic. Set it to 1 (for enable) or 0 (to disable).
    By default symbolic links are followed.
  * Perl Filter and Perl API.
  * For zebra.cfg, if no profilePath is specified, directory
    (prefix)/share/idzebra/tab (/etc/idzebra) is used.
  * Bug fix: sort index was not properly modified on record
    updates/deletes.
  * Fix handling of character entities for sgml filter.
  * Fix character encoding of scan response terms.
  * Fix character decoding of scan request terms.
  * Fix ESpec handling (requires YAZ 1.9.1)
  * Fix searches for complete fields.
  * Fix MARC transfer. MARC fields had wrong data for multiple fields.
  * XML record reader supports external system entities.
  * New .abs-directive "xpath" that takes one argument: "enable"
    or "disable" to enable and disable XPath -indexing. If no "xpath"
    direcive is found in .abs-file , XPath-indexing is disabled to ensure
    backwards compatibility. For missing .abs-files XPath-indexing is
    enabled so that such records are searchable.
  * Zebra warns about missing .abs-file only once (for each type).
  * Fixed a bug in file update where already-inserted files could be
    treated as "new".
* Mon Nov 25 2002 ke@suse.de
- Rename zebra-engine to idzebra to avoid naming clash with GNU zebra.
- Update to version 1.3.0; extract from
  http://www.indexdata.dk/zebra/CHANGELOG:
  * Zebra license changed to GNU GPL.
  * New Zebra API. Locking system re-implemented.
  * XPATH-like queries used when RPN string attributes are used, eg.
    @attr 1=/portal/title sometitle
    @attr 1=/portal/title[@xml:lang=da] danishtitle
    @attr 1=/portal/title/@xml:lang da
    @attr 1=//title sometitle
  * Zebra uses UTF-8 internally: Setting in zebra.cfg; encoding of
    International strings is UTF-8 by default; new directive "encoding"
    in .abs-files.
  * XML filter (-t grs.xml).
  * Multiple registers.
* Mon Aug  5 2002 ke@suse.de
- Add expat to #neededforbuild on account of yaz.
* Mon May 13 2002 ke@suse.de
- New package: version 1.1.
